@@ -156,6 +156,17 @@ class AltiumRun:
         self.set_function_name(function_name)
         self.set_function_parameters(*args)
 
+    # this one for me
+    def set_function_top(self, function_name: str, *args: List[Any]) -> None:
+        r"""Set the function name and arguments of the Altium script function needed to be run.
+
+        :param function_name: The name of the function to run in the Altium script as string.
+        :param args: The arguments given to the Altium script function.
+        """
+        self.add_script(self._project_path + "/updateSitNum0302.pas")
+        self.set_function_name(function_name)
+        self.set_function_parameters(*args)
+
     def run(self, wait_until_finished: bool = True, timeout: float = 10) -> bool:
         r"""Runs the script based on the settings defined.
 
